@@ -34,6 +34,24 @@ from bzrlib.trace import (
     note,
     )
 
+from bzrlib.plugins.rewrite import gettext
+
+
+def finish_rebase(state, wt, replace_map, replayer):
+    from bzrlib.plugins.rewrite.rebase import (
+        rebase,
+        )
+    try:
+        # Start executing plan from current Branch.last_revision()
+        rebase(wt.branch.repository, replace_map, replayer)
+    except ConflictsInTree:
+        raise BzrCommandError(gettext("A conflict occurred replaying a commit."
+            " Resolve the conflict and run 'bzr rebase-continue' or "
+            "run 'bzr rebase-abort'."))
+    # Remove plan file
+    state.remove_plan()
+
+
 class cmd_rebase(Command):
     """Re-base a branch.
 
@@ -101,8 +119,8 @@ class cmd_rebase(Command):
             rebase_todo,
             )
         if revision is not None and pending_merges:
-            raise BzrCommandError(
-                "--revision and --pending-merges are mutually exclusive")
+            raise BzrCommandError(gettext(
+                "--revision and --pending-merges are mutually exclusive"))
 
         wt = WorkingTree.open_containing(directory)[0]
         wt.lock_write()
@@ -114,16 +132,16 @@ class cmd_rebase(Command):
                 else:
                     upstream_location = wt.branch.get_parent()
                     if upstream_location is None:
-                        raise BzrCommandError("No upstream branch specified.")
-                    note("Rebasing on %s", upstream_location)
+                        raise BzrCommandError(gettext("No upstream branch specified."))
+                    note(gettext("Rebasing on %s"), upstream_location)
             upstream = Branch.open_containing(upstream_location)[0]
             upstream_repository = upstream.repository
             upstream_revision = upstream.last_revision()
             # Abort if there already is a plan file
             if state.has_plan():
-                raise BzrCommandError("A rebase operation was interrupted. "
+                raise BzrCommandError(gettext("A rebase operation was interrupted. "
                     "Continue using 'bzr rebase-continue' or abort using 'bzr "
-                    "rebase-abort'")
+                    "rebase-abort'"))
 
             start_revid = None
             stop_revid = None
@@ -137,16 +155,16 @@ class cmd_rebase(Command):
                     if revision[1] is not None:
                         stop_revid = revision[1].as_revision_id(wt.branch)
                 else:
-                    raise BzrCommandError(
-                        "--revision takes only one or two arguments")
+                    raise BzrCommandError(gettext(
+                        "--revision takes only one or two arguments"))
 
             if pending_merges:
                 wt_parents = wt.get_parent_ids()
                 if len(wt_parents) in (0, 1):
-                    raise BzrCommandError("No pending merges present.")
+                    raise BzrCommandError(gettext("No pending merges present."))
                 elif len(wt_parents) > 2:
-                    raise BzrCommandError(
-                        "Rebasing more than one pending merge not supported")
+                    raise BzrCommandError(gettext(
+                        "Rebasing more than one pending merge not supported"))
                 stop_revid = wt_parents[1]
                 assert stop_revid is not None, "stop revid invalid"
 
@@ -172,11 +190,11 @@ class cmd_rebase(Command):
 
             if start_revid is None:
                 if not onto_unique:
-                    self.outf.write("No revisions to rebase.\n")
+                    self.outf.write(gettext("No revisions to rebase.\n"))
                     return
                 if not our_new:
-                    self.outf.write("Base branch is descendant of current "
-                        "branch. Pulling instead.\n")
+                    self.outf.write(gettext("Base branch is descendant of current "
+                        "branch. Pulling instead.\n"))
                     if not dry_run:
                         wt.pull(upstream, onto)
                     return
@@ -194,7 +212,7 @@ class cmd_rebase(Command):
 
             if verbose or dry_run:
                 todo = list(rebase_todo(wt.branch.repository, replace_map))
-                note('%d revisions will be rebased:' % len(todo))
+                note(gettext('%d revisions will be rebased:') % len(todo))
                 for revid in todo:
                     note("%s" % revid)
 
@@ -202,17 +220,9 @@ class cmd_rebase(Command):
                 # Write plan file
                 state.write_plan(replace_map)
 
-                # Start executing plan
-                try:
-                    rebase(wt.branch.repository, replace_map,
-                        WorkingTreeRevisionRewriter(wt, state,
-                            merge_type=merge_type))
-                except ConflictsInTree:
-                    raise BzrCommandError("A conflict occurred replaying a "
-                        "commit. Resolve the conflict and run "
-                        "'bzr rebase-continue' or run 'bzr rebase-abort'.")
-                # Remove plan file
-                state.remove_plan()
+                replayer = WorkingTreeRevisionRewriter(wt, state, merge_type=merge_type)
+
+                finish_rebase(state, wt, replace_map, replayer)
         finally:
             wt.unlock()
 
@@ -258,7 +268,6 @@ class cmd_rebase_continue(Command):
     def run(self, merge_type=None, directory="."):
         from bzrlib.plugins.rewrite.rebase import (
             RebaseState1,
-            rebase,
             WorkingTreeRevisionRewriter,
             )
         from bzrlib.workingtree import WorkingTree
@@ -269,27 +278,19 @@ class cmd_rebase_continue(Command):
             replayer = WorkingTreeRevisionRewriter(wt, state, merge_type=merge_type)
             # Abort if there are any conflicts
             if len(wt.conflicts()) != 0:
-                raise BzrCommandError("There are still conflicts present. "
+                raise BzrCommandError(gettext("There are still conflicts present. "
                                       "Resolve the conflicts and then run "
-                                      "'bzr resolve' and try again.")
+                                      "'bzr resolve' and try again."))
             # Read plan file
             try:
                 replace_map = state.read_plan()[1]
             except NoSuchFile:
-                raise BzrCommandError("No rebase to continue")
+                raise BzrCommandError(gettext("No rebase to continue"))
             oldrevid = state.read_active_revid()
             if oldrevid is not None:
                 oldrev = wt.branch.repository.get_revision(oldrevid)
                 replayer.commit_rebase(oldrev, replace_map[oldrevid][0])
-            try:
-                # Start executing plan from current Branch.last_revision()
-                rebase(wt.branch.repository, replace_map, replayer)
-            except ConflictsInTree:
-                raise BzrCommandError("A conflict occurred replaying a commit."
-                    " Resolve the conflict and run 'bzr rebase-continue' or "
-                    "run 'bzr rebase-abort'.")
-            # Remove plan file
-            state.remove_plan()
+            finish_rebase(state, wt, replace_map, replayer)
         finally:
             wt.unlock()
 
@@ -318,12 +319,12 @@ class cmd_rebase_todo(Command):
             try:
                 replace_map = state.read_plan()[1]
             except NoSuchFile:
-                raise BzrCommandError("No rebase in progress")
+                raise BzrCommandError(gettext("No rebase in progress"))
             currentrevid = state.read_active_revid()
             if currentrevid is not None:
-                note("Currently replaying: %s" % currentrevid)
+                note(gettext("Currently replaying: %s") % currentrevid)
             for revid in rebase_todo(wt.branch.repository, replace_map):
-                note("%s -> %s" % (revid, replace_map[revid][0]))
+                note(gettext("{0} -> {1}").format(revid, replace_map[revid][0]))
         finally:
             wt.unlock()
 
@@ -365,10 +366,10 @@ class cmd_replay(Command):
                 for revno in range(from_revno, to_revno + 1):
                     todo.append(from_branch.get_rev_id(revno))
             else:
-                raise BzrCommandError(
-                    "--revision takes only one or two arguments")
+                raise BzrCommandError(gettext(
+                    "--revision takes only one or two arguments"))
         else:
-            raise BzrCommandError("--revision is mandatory")
+            raise BzrCommandError(gettext("--revision is mandatory"))
 
         wt = WorkingTree.open(directory)
         wt.lock_write()
@@ -378,7 +379,7 @@ class cmd_replay(Command):
             pb = ui.ui_factory.nested_progress_bar()
             try:
                 for revid in todo:
-                    pb.update("replaying commits", todo.index(revid), len(todo))
+                    pb.update(gettext("replaying commits"), todo.index(revid), len(todo))
                     wt.branch.repository.fetch(from_branch.repository, revid)
                     newrevid = regenerate_default_revid(wt.branch.repository, revid)
                     replayer(revid, newrevid, [wt.last_revision()])
@@ -421,7 +422,7 @@ class cmd_rebase_foreign(Command):
     takes_options = ['verbose',
         Option("idmap-file", help="Write map with old and new revision ids.",
                type=str),
-        Option('directory', 
+        Option('directory',
             short_name='d',
             help="Branch to replay onto, rather than the one containing the working directory.",
             type=str)
@@ -456,12 +457,12 @@ class cmd_rebase_foreign(Command):
         stored_loc = branch_to.get_parent()
         if new_base is None:
             if stored_loc is None:
-                raise BzrCommandError("No pull location known or"
-                                             " specified.")
+                raise BzrCommandError(gettext("No pull location known or"
+                                             " specified."))
             else:
                 display_url = urlutils.unescape_for_display(stored_loc,
                         self.outf.encoding)
-                self.outf.write("Using saved location: %s\n" % display_url)
+                self.outf.write(gettext("Using saved location: %s\n") % display_url)
                 new_base = Branch.open(stored_loc)
         else:
             new_base = Branch.open(new_base)
@@ -495,7 +496,7 @@ class cmd_rebase_foreign(Command):
             branch_to.unlock()
 
         if renames == {}:
-            note("Nothing to do.")
+            note(gettext("Nothing to do."))
 
         if idmap_file is not None:
             f = open(idmap_file, 'w')
