@@ -19,15 +19,14 @@
 import os
 
 from bzrlib import (
+    config as _mod_config,
     osutils,
     )
-from bzrlib.config import Config
 from bzrlib.errors import (
     BzrError,
     NoSuchFile,
     UnknownFormatError,
     NoCommonAncestor,
-    NoSuchId,
     UnrelatedBranches,
     )
 from bzrlib.generate_ids import gen_revision_id
@@ -113,6 +112,7 @@ class RebaseState1(RebaseState):
 
     def write_plan(self, replace_map):
         """See `RebaseState`."""
+        self.wt.update_feature_flags({"rebase-v1": "write-required"})
         content = marshall_rebase_plan(self.wt.branch.last_revision_info(),
             replace_map)
         assert type(content) == str
@@ -120,6 +120,7 @@ class RebaseState1(RebaseState):
 
     def remove_plan(self):
         """See `RebaseState`."""
+        self.wt.update_feature_flags({"rebase-v1": None})
         self.transport.put_bytes(REBASE_PLAN_FILENAME, '')
 
     def write_active_revid(self, revid):
@@ -377,14 +378,15 @@ def rebase(repository, replace_map, revision_rewriter):
         pb.finished()
 
 
-class ReplayParentsInconsistent(BzrError):
-    """Raised when parents were inconsistent."""
-    _fmt = """Parents were inconsistent while replaying commit for file id %(fileid)s, revision %(revid)s."""
-
-    def __init__(self, fileid, revid):
-        BzrError.__init__(self)
-        self.fileid = fileid
-        self.revid = revid
+def wrap_iter_changes(old_iter_changes, map_tree):
+    for (file_id, path, changed_content, versioned, (old_parent, new_parent), name, kind,
+            executable) in old_iter_changes:
+        if old_parent is not None:
+            old_parent = map_tree.new_id(old_parent)
+        if new_parent is not None:
+            new_parent = map_tree.new_id(new_parent)
+        yield (map_tree.new_id(file_id), path, changed_content, versioned,
+                (old_parent, new_parent), name, kind, executable)
 
 
 class CommitBuilderRevisionRewriter(object):
@@ -397,37 +399,6 @@ class CommitBuilderRevisionRewriter(object):
         self.repository = repository
         self.map_ids = map_ids
 
-    def _process_file(self, old_ie, oldtree, oldrevid, newrevid,
-                      old_parent_invs, new_parent_invs, path):
-        ie = old_ie.copy()
-        # Either this file was modified last in this revision,
-        # in which case it has to be rewritten
-        if old_ie.revision == oldrevid:
-            if self.repository.texts.has_key((ie.file_id, newrevid)):
-                # Use the existing text
-                ie.revision = newrevid
-            else:
-                # Create a new text
-                ie.revision = None
-        else:
-            # or it was already there before the commit, in
-            # which case the right revision should be used
-            # one of the old parents had this revision, so find that
-            # and then use the matching new parent
-            old_file_id = oldtree.inventory.path2id(path)
-            assert old_file_id is not None
-            ie = None
-            for (old_pinv, new_pinv) in zip(old_parent_invs, new_parent_invs):
-                if (old_pinv.has_id(old_file_id) and
-                    old_pinv[old_file_id].revision == old_ie.revision):
-                    try:
-                        ie = new_pinv[old_ie.file_id].copy()
-                    except NoSuchId:
-                        raise ReplayParentsInconsistent(old_ie.file_id, old_ie.revision)
-                    break
-            assert ie is not None
-        return ie
-
     def _get_present_revisions(self, revids):
         return tuple([p for p in revids if self.repository.has_revision(p)])
 
@@ -447,35 +418,38 @@ class CommitBuilderRevisionRewriter(object):
         revprops = dict(oldrev.properties)
         revprops[REVPROP_REBASE_OF] = oldrevid
 
-        builder = self.repository.get_commit_builder(branch=None,
-            parents=new_parents, config=Config(), committer=oldrev.committer,
-            timestamp=oldrev.timestamp, timezone=oldrev.timezone,
-            revprops=revprops, revision_id=newrevid)
+        # Check what new_ie.file_id should be
+        # use old and new parent trees to generate new_id map
+        nonghost_oldparents = self._get_present_revisions(oldrev.parent_ids)
+        nonghost_newparents = self._get_present_revisions(new_parents)
+        oldtree = self.repository.revision_tree(oldrevid)
+        if self.map_ids:
+            fileid_map = map_file_ids(self.repository, nonghost_oldparents,
+                nonghost_newparents)
+            mappedtree = MapTree(oldtree, fileid_map)
+        else:
+            mappedtree = oldtree
+
         try:
-            # Check what new_ie.file_id should be
-            # use old and new parent inventories to generate new_id map
-            nonghost_oldparents = self._get_present_revisions(oldrev.parent_ids)
-            nonghost_newparents = self._get_present_revisions(new_parents)
-            oldtree = self.repository.revision_tree(oldrevid)
-            if self.map_ids:
-                fileid_map = map_file_ids(self.repository, nonghost_oldparents,
-                    nonghost_newparents)
-                mappedtree = MapTree(oldtree, fileid_map)
-            else:
-                mappedtree = oldtree
-            old_parent_invs = list(self.repository.iter_inventories(nonghost_oldparents))
-            new_parent_invs = list(self.repository.iter_inventories(nonghost_newparents))
-            pb = ui.ui_factory.nested_progress_bar()
-            try:
-                for i, (path, old_ie) in enumerate(mappedtree.inventory.iter_entries()):
-                    pb.update('upgrading file', i, len(mappedtree.inventory))
-                    ie = self._process_file(old_ie, oldtree, oldrevid, newrevid,
-                        old_parent_invs, new_parent_invs, path)
-                    builder.record_entry_contents(ie,
-                            new_parent_invs, path, mappedtree,
-                            mappedtree.path_content_summary(path))
-            finally:
-                pb.finished()
+            old_base = nonghost_oldparents[0]
+        except IndexError:
+            old_base = NULL_REVISION
+        try:
+            new_base = new_parents[0]
+        except IndexError:
+            new_base = NULL_REVISION
+        old_base_tree = self.repository.revision_tree(old_base)
+        old_iter_changes = oldtree.iter_changes(old_base_tree)
+        iter_changes = wrap_iter_changes(old_iter_changes, mappedtree)
+        builder = self.repository.get_commit_builder(branch=None,
+            parents=new_parents, committer=oldrev.committer,
+            timestamp=oldrev.timestamp, timezone=oldrev.timezone,
+            revprops=revprops, revision_id=newrevid,
+            config_stack=_mod_config.GlobalStack())
+        try:
+            for (file_id, relpath, fs_hash) in builder.record_iter_changes(
+                    mappedtree, new_base, iter_changes):
+                pass
             builder.finish_inventory()
             return builder.commit(oldrev.message)
         except:
