@@ -28,6 +28,7 @@ from bzrlib.graph import (
     )
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tests import TestCase, TestCaseWithTransport
+from bzrlib.tests.matchers import RevisionHistoryMatches
 
 from bzrlib.plugins.rewrite.rebase import (
     marshall_rebase_plan,
@@ -40,7 +41,6 @@ from bzrlib.plugins.rewrite.rebase import (
     REBASE_CURRENT_REVID_FILENAME,
     RebaseState1,
     ReplaySnapshotError,
-    ReplayParentsInconsistent,
     WorkingTreeRevisionRewriter,
     )
 
@@ -82,7 +82,7 @@ class ConversionTests(TestCaseWithTransport):
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bloe")
         wt.set_last_revision("bla")
-        b.set_revision_history(["bla"])
+        b.generate_revision_history("bla")
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bla2")
 
@@ -109,7 +109,7 @@ class PlanCreatorTests(TestCaseWithTransport):
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bloe")
         wt.set_last_revision("bla")
-        b.set_revision_history(["bla"])
+        b.generate_revision_history("bla")
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bla2")
 
@@ -130,7 +130,7 @@ class PlanCreatorTests(TestCaseWithTransport):
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bloe")
         wt.set_last_revision("bla")
-        b.set_revision_history(["bla"])
+        b.generate_revision_history("bla")
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bla2")
         file('hello', 'w').write('universe')
@@ -155,17 +155,17 @@ class PlanCreatorTests(TestCaseWithTransport):
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bloe")
         wt.set_last_revision("bla")
-        b.set_revision_history(["bla"])
+        b.generate_revision_history("bla")
         file('hello', 'w').write('world')
         wt.commit(message='change hello', rev_id="bla2")
         file('hello', 'w').write('universe')
         wt.commit(message='change hello again', rev_id="bla3")
         wt.set_last_revision("bla")
-        b.set_revision_history(["bla"])
+        b.generate_revision_history("bla")
         file('hello', 'w').write('somebar')
         wt.commit(message='change hello yet again', rev_id="blie")
         wt.set_last_revision(NULL_REVISION)
-        b.set_revision_history([])
+        b.generate_revision_history(NULL_REVISION)
         wt.add('hello')
         wt.commit(message='add hello', rev_id="lala")
 
@@ -350,7 +350,9 @@ class RebaseTodoTests(TestCase):
                 list(rebase_todo(Repository(), { "bla": ("bloe", []),
                                                  "ha": ("hee", [])})))
 
+
 class ReplaySnapshotTests(TestCaseWithTransport):
+
     def test_single_revision(self):
         wt = self.make_branch_and_tree(".")
         self.build_tree(['afile'])
@@ -369,26 +371,6 @@ class ReplaySnapshotTests(TestCaseWithTransport):
         inv = wt.branch.repository.get_inventory("newcommit")
         self.assertEquals("newcommit", inv[inv.path2id("afile")].revision)
 
-    def test_parents_different(self):
-        """CommitBuilderRevisionRewriter() relies on the fact that the contents of
-        the old and new parents is equal (at least concerning tree shape). If
-        it turns out it isn't, an exception should be raised."""
-        wt = self.make_branch_and_tree(".")
-        wt.commit("bloe", rev_id="base")
-        self.build_tree(['afile', 'notherfile'])
-        wt.add(["afile"])
-        wt.commit("bla", rev_id="oldparent")
-        wt.add(["notherfile"])
-        wt.commit("bla", rev_id="oldcommit")
-        # this should raise an exception since oldcommit is being rewritten
-        # but 'afile' is present in the old parents but not in the new ones.
-        wt.branch.repository.lock_write()
-        self.assertRaises(
-                ReplayParentsInconsistent,
-                CommitBuilderRevisionRewriter(wt.branch.repository),
-                "oldcommit", "newcommit", ("base",))
-        wt.branch.repository.unlock()
-
     def test_two_revisions(self):
         wt = self.make_branch_and_tree("old")
         self.build_tree_contents([('old/afile', 'afilecontents'), ('old/notherfile', 'notherfilecontents')])
@@ -648,15 +630,11 @@ class TestReplayWorkingtree(TestCaseWithTransport):
         replayer.commit_rebase(oldrev, "E'")
         newrev = newwt.branch.repository.get_revision("E'")
         self.assertEquals(["D'"], newrev.parent_ids)
-        self.assertEquals(["A", "B", "C", "D'", "E'"],
-                          newwt.branch.revision_history())
+        self.assertThat(newwt.branch,
+                RevisionHistoryMatches(["A", "B", "C", "D'", "E'"]))
 
 
 class TestReplaySnapshotError(TestCase):
+
     def test_create(self):
         ReplaySnapshotError("message")
-
-
-class TestReplayParentsInconsistent(TestCase):
-    def test_create(self):
-        ReplayParentsInconsistent("afileid", "arevid")
